Product class

Constructors

Product({String? id, required String name, required double price, required int quantity, required String imgfile, required DateTime timestamp, required DateTime actualdateadded})
Product.fromFirestore(Document doc)
factory

Properties

actualdateadded DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
imgfile String
final
name String
final
price double
final
quantity int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFirestore() Map<String, dynamic>
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited